@@ -619,7 +619,7 @@ void ascpu_update()
 {
 	time_t cur_time;
 	cur_time = time(0);
-	if ( (cur_time - last_time) >= state.update_interval ) {
+	if ( abs(cur_time - last_time) >= state.update_interval ) {
 		last_time = cur_time;
 		read_stat();
 		update_running();
